@@ -9,6 +9,7 @@ import {disposeScene} from './three-memory-cleaner';
 import diff from 'immutablediff';
 import {initPointerLock} from "./pointer-lock-navigation";
 import {firstPersonOnKeyDown, firstPersonOnKeyUp} from "./libs/first-person-controls";
+import * as SharedStyle from '../../shared-style';
 
 export default class Viewer3DFirstPerson extends React.Component {
 
@@ -52,7 +53,7 @@ export default class Viewer3DFirstPerson extends React.Component {
     let sceneOnTop = new Three.Scene();
 
     //RENDERER
-    this.renderer.setClearColor(new Three.Color(0xffffff));
+    this.renderer.setClearColor(new Three.Color(SharedStyle.COLORS.white));
     this.renderer.setSize(this.width, this.height);
 
     // LOAD DATA
@@ -79,7 +80,7 @@ export default class Viewer3DFirstPerson extends React.Component {
     scene3D.add(light);
 
     // Add another light
-    let pointLight = new Three.PointLight(0xffffff, 0.4, 1000);
+    let pointLight = new Three.PointLight(SharedStyle.COLORS.white, 0.4, 1000);
     pointLight.position.set(0, 0, 0);
     scene3D.add(pointLight);
 
@@ -128,7 +129,7 @@ export default class Viewer3DFirstPerson extends React.Component {
 
     let pointer = new Three.Object3D();
 
-    let pointerMaterial = new Three.MeshBasicMaterial({depthTest: false, depthWrite: false, color: 0x000000});
+    let pointerMaterial = new Three.MeshBasicMaterial({depthTest: false, depthWrite: false, color: SharedStyle.COLORS.black});
     let pointerGeometry1 = new Three.Geometry();
     pointerGeometry1.vertices.push(new Three.Vector3(-10, 0, 0));
     pointerGeometry1.vertices.push(new Three.Vector3(10, 0, 0));
